package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*@`!````@!H``#0````T`@$`&````#0`(``)
M`"@`&0`8``8````T````-````#0````@`0``(`$```0````$`````P```'@!
M``!X`0``>`$``!,````3````!`````$````!````````````````````*)0`
M`"B4```%```````!``$```#H_@``Z/X!`.C^`0!0`@``9`(```8```````$`
M`@```/#^``#P_@$`\/X!`!`!```0`0``!@````0````$````5`$``%0!``!4
M`0``)````"0````$````!`````0````(E```")0```B4```@````(`````0`
M```$````4>5T9```````````````````````````!@````@```!2Y71DZ/X`
M`.C^`0#H_@$`&`$``!@!```$`````0````0````4`````P```$=.50#W?KI&
M9_AK9ZX;&(<"M1Y(&^7Z!R]L:6(O;&0M;&EN=7@N<V\N,@``$0```$4````(
M````"``````0$`0E0`2`*```!*"&`(2`@0`""R@%&#B`$D&*```(`````$4`
M``!(````2P```$P```!4````50```%8`````````6````%D```!:````6P``
M`%P```!?``````````````!NQ=\?SMY'+6M_FGPNQ9NVU&34?"'_Y`[9<5@<
MXD?&`;(!BV^L2^/`0OK7A\+E/RRZXY)\^J%L8)E/PYMK"4/69Z_,9D)%U>R)
M!W#3,V+;[16,)<P-.I<+?ZF<F[#<:Q3@IP(*:QJ>4*/@^TD`````````````
M````````Q`,`````````````$@```.0``````````````!(```#P`@``````
M```````1````P@(`````````````$@```)8``````````````!(```!=`0``
M```````````2````TP$`````````````$@```%@"`````````````!(```#Z
M```````````````2`````0``````````````(````'0!`````````````!(`
M``#X`@`````````````2````N@$`````````````$@````$"````````````
M`!(````H`@`````````````2````*P$`````````````$@```/H!````````
M`````!(````;`0`````````````2````#0$`````````````$@```/(!````
M`````````!(````0```````````````@````>P$`````````````$@```#D"
M`````````````!(```#N`@`````````````1````CP(`````````````$@``
M`"P``````````````"`````2`@`````````````2````1@``````````````
M$@```$("`````````````!(```!C```````````````6````30$`````````
M````$@```,P!`````````````!(```!V```````````````2````TP``````
M````````$@```(<``````````````!(```#"`0`````````````2````E@(`
M````````````(@```-<"`````````````!(```"U`0`````````````2````
MZ`(`````````````$@```+<``````````````!(````,`@`````````````2
M````(0(`````````````$@````H#`````````````!$```"L`@``````````
M```2````/P$`````````````$@```'@"`````````````!(```#N````````
M```````2````I`$`````````````$@```*4"`````````````!(```"S`@``
M```````````2````ZP$`````````````$@```*(``````````````!(````'
M`@`````````````2````:`$`````````````$@```$H"`````````````!(`
M``#I```````````````2````W`$`````````````$@```,8`````````````
M`!$```#C`0`````````````2````A@$`````````````$0```,D"````````
M`````!(````T`0`````````````2````N@(`````````````$@```%0`````
M`````````!(```!F`@`````````````2````T`(`````````````$@```(@"
M`````````````!$```#-`P``##H``#@!```2``P`(@0``&`P``!@!P``$@`,
M`',"```P&```4`(``!(`#`!$`P``5",``"`````2``P`8@,``,`W``!,`@``
M$@`,`$@$``!T(P``/`,``!(`#``(!```.`$"```````0`!8`50,``+`F```X
M````$@`,`'@#````+```?````!(`#`#9`P``+%,```0````1``X`]0,``&10
M```P`0``$@`,```$```P(@``2````!(`#``=!```3`$"```````0`!8`-@0`
M`/`N``!P`0``$@`,`%\$``!\+```P````!(`#`#H`P`````"```````0`!0`
MG`,``.@F```X`0``$@`,`"\$```X`0(``````!``%0!5!```'``"``0````1
M`!0`[@,``(`:````````$@`,`!0$``#T3P``<````!(`#`#J`P`````"````
M```@`!0`L@,``,`N```P````$@`,`)4!```$``(``````!$`%`"&`P``>"(`
M`-P````2``P`J`,``)11``!$`0``$@`,`&<$```@*```X`,``!(`#```7U]G
M;6]N7W-T87)T7U\`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?
M<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I
M;FET,P!03%]C=7)R96YT7V-O;G1E>'0`4&5R;%]A=&9O<FM?;&]C:P!P97)L
M7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!0
M97)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!P
M97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?
M<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`
M<&5R;%]D97-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L
M7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A<`!?7V9P
M<V-R7W9A;'5E<P!?7W-T86-K7V-H:U]F86EL`&5X:70`;'-E96LV-`!R96%D
M9&ER-C0`<W1R9'5P`&-L;W-E9&ER`&]P96XV-`!S=')R8VAR`'5N;&EN:P!M
M96UM;W9E`'-T<G1O:P!R;61I<@!R96%D`&UK9&ER`%]?=F9P<FEN=&9?8VAK
M`&=E='!I9`!?7VQS=&%T-C1?=&EM938T`')E861L:6YK`')E86QL;V,`7U]S
M<')I;G1F7V-H:P!?7V9P<FEN=&9?8VAK`%]?;&EB8U]S=&%R=%]M86EN`%]?
M<W1A=#8T7W1I;64V-`!S=&1E<G(`;65M8VAR`%]?8WAA7V9I;F%L:7IE`'-T
M<F-H<@!M96UC;7``;65M<V5T`&]P96YD:7(`9V5T=6ED`&%C8V5S<P!M96UC
M<'D`7U]E<G)N;U]L;V-A=&EO;@!A8F]R=`!?7V5N=FER;VX`7U]R96=I<W1E
M<E]A=&9O<FL`7U]S=&%C:U]C:&M?9W5A<F0`;&EB<&5R;"YS;RXU+C0P`&QI
M8F,N<V\N-@!L9"UL:6YU>"YS;RXR`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A
M<V5N86UE`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A
M<E]C=7)R96YT7V5X96-?<')O8P!P87)?9&ER;F%M90!S:&%?9FEN86P`9V5T
M7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7TE/7W-T9&EN
M7W5S960`7U]D871A7W-T87)T`'-H85]U<&1A=&4`>'-?:6YI=`!?7V)S<U]S
M=&%R=`!S:&%?:6YI=`!?96YD`'!A<E]M:W1M<&1I<@!?961A=&$`<&%R7W-E
M='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P87)?9&EE`'!A
M<E]I;FET7V5N=@!'3$E"0U\R+C0`1TQ)0D-?,BXS-`!'3$E"0U\R+C,N,@!'
M3$E"0U\R+C,N-`!'3$E"0U\R+C(``````@`!``(``@`!``$``@`#``$``0`"
M``0``@`"``4``0`"``$``0`"``$``0`"``(``@`!``,``0`"``$``0`"``$`
M`0`!``(``@`"``(``@`!``(``@`&``(``0`%``$`!P`"``(``@`!``(``0`#
M``(``@`!``(``0`"``$``@`!``4``@`"``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`V`P``$```
M`"`````4:6D-```&`'0$`````````0`%`"P#```0`````````!1I:0T```<`
M=`0``!````"TD98&```%`'X$```0````<AEI"0``!`")!```$````'09:0D`
M``,`E00``!`````2:6D-```"`*$$````````Z/X!`*4```!\&P``[/X!`*4`
M```H&P``#``"`*4````,``(`'``"`*4```"`5@``G!H```%'````````H!H`
M``%"````````I!H```$H````````!`$"`*,#````````"`$"`*,)````````
M#`$"`*,*````````$`$"`*,5````````%`$"`*,:````````&`$"`)<>````
M````'`$"`*,?````````(`$"`*,A````````)`$"`*,E````````*`$"`*,L
M````````+`$"`*,[````````,`$"`*,]````````-`$"`*-$````````+``"
M`*0!````````,``"`*0"````````-``"`*0$````````.``"`*0%````````
M/``"`*0&````````0``"`*0'````````1``"`*0(````````2``"`*0*````
M````3``"`*0+````````4``"`*0,````````5``"`*0-````````6``"`*0.
M````````7``"`*0/````````8``"`*00````````9``"`*01````````:``"
M`*02````````;``"`*03````````<``"`*04````````=``"`*06````````
M>``"`*07````````?``"`*09````````@``"`*0;````````A``"`*0<````
M````B``"`*0=````````C``"`*0@````````D``"`*0B````````E``"`*0C
M````````F``"`*0D````````G``"`*0E````````H``"`*0F````````I``"
M`*0G````````J``"`*0I````````K``"`*0J````````L``"`*0K````````
MM``"`*0M````````N``"`*0N````````O``"`*0O````````P``"`*0P````
M````Q``"`*0Q````````R``"`*0R````````S``"`*0S````````T``"`*0T
M````````U``"`*0U````````V``"`*0V````````W``"`*0W````````X``"
M`*0X````````Y``"`*0Y````````Z``"`*0Z````````[``"`*0\````````
M\``"`*0^````````]``"`*0_````````^``"`*1`````````_``"`*1!````
M``````$"`*1#`````````````````````````````,8O!\<&W.8O##PB3P70
MS@$8(0.-\VX$T0,!"0`&H`D`(.X!`.P````0`0``"0`)``D`"0`)``D`"0`)
M``D`"0#C;R9/]F[V;`L`"0`%T`)@!B\#T`)@*T#V8`D`"0`)````````````
M!-#.`"M`"0#"4`/1*T#!4`D`"0`,``````````30S@`K0`D`PE`#T2M`P5`)
M``D`$`````P````$T,X`*T`)`,)0`]$K0,%0"0`)`!0````8````!-#.`"M`
M"0#"4`/1*T#!4`D`"0`8````)`````30S@`K0`D`PE`#T2M`P5`)``D`'```
M`#`````$T,X`*T`)`,)0`]$K0,%0"0`)`"`````\````!-#.`"M`"0#"4`/1
M*T#!4`D`"0`D````2`````30S@`K0`D`PE`#T2M`P5`)``D`*````%0````$
MT,X`*T`)`,)0`]$K0,%0"0`)`"P```!@````!-#.`"M`"0#"4`/1*T#!4`D`
M"0`P````;`````30S@`K0`D`PE`#T2M`P5`)``D`-````'@````$T,X`*T`)
M`,)0`]$K0,%0"0`)`#@```"$````!-#.`"M`"0#"4`/1*T#!4`D`"0`\````
MD`````30S@`K0`D`PE`#T2M`P5`)``D`0````)P````$T,X`*T`)`,)0`]$K
M0,%0"0`)`$0```"H````!-#.`"M`"0#"4`/1*T#!4`D`"0!(````M`````30
MS@`K0`D`PE`#T2M`P5`)``D`3````,`````$T,X`*T`)`,)0`]$K0,%0"0`)
M`%````#,````!-#.`"M`"0#"4`/1*T#!4`D`"0!4````V`````30S@`K0`D`
MPE`#T2M`P5`)``D`6````.0````$T,X`*T`)`,)0`]$K0,%0"0`)`%P```#P
M````!-#.`"M`"0#"4`/1*T#!4`D`"0!@````_`````30S@`K0`D`PE`#T2M`
MP5`)``D`9`````@!```$T,X`*T`)`,)0`]$K0,%0"0`)`&@````4`0``!-#.
M`"M`"0#"4`/1*T#!4`D`"0!L````(`$```30S@`K0`D`PE`#T2M`P5`)``D`
M<````"P!```$T,X`*T`)`,)0`]$K0,%0"0`)`'0````X`0``!-#.`"M`"0#"
M4`/1*T#!4`D`"0!X````1`$```30S@`K0`D`PE`#T2M`P5`)``D`?````%`!
M```$T,X`*T`)`,)0`]$K0,%0"0`)`(````!<`0``!-#.`"M`"0#"4`/1*T#!
M4`D`"0"$````:`$```30S@`K0`D`PE`#T2M`P5`)``D`B````'0!```$T,X`
M*T`)`,)0`]$K0,%0"0`)`(P```"``0``!-#.`"M`"0#"4`/1*T#!4`D`"0"0
M````C`$```30S@`K0`D`PE`#T2M`P5`)``D`E````)@!```$T,X`*T`)`,)0
M`]$K0,%0"0`)`)@```"D`0``!-#.`"M`"0#"4`/1*T#!4`D`"0"<````L`$`
M``30S@`K0`D`PE`#T2M`P5`)``D`H````+P!```$T,X`*T`)`,)0`]$K0,%0
M"0`)`*0```#(`0``!-#.`"M`"0#"4`/1*T#!4`D`"0"H````U`$```30S@`K
M0`D`PE`#T2M`P5`)``D`K````.`!```$T,X`*T`)`,)0`]$K0,%0"0`)`+``
M``#L`0``!-#.`"M`"0#"4`/1*T#!4`D`"0"T````^`$```30S@`K0`D`PE`#
MT2M`P5`)``D`N`````0"```$T,X`*T`)`,)0`]$K0,%0"0`)`+P````0`@``
M!-#.`"M`"0#"4`/1*T#!4`D`"0#`````'`(```30S@`K0`D`PE`#T2M`P5`)
M``D`Q````"@"```$T,X`*T`)`,)0`]$K0,%0"0`)`,@````T`@``!-#.`"M`
M"0#"4`/1*T#!4`D`"0#,````0`(```30S@`K0`D`PE`#T2M`P5`)``D`T```
M`$P"```$T,X`*T`)`,)0`]$K0,%0"0`)`-0```!8`@``!-#.`"M`"0#"4`/1
M*T#!4`D`"0#8````9`(```30S@`K0`D`PE`#T2M`P5`)``D`W````'`"```$
MT,X`*T`)`,)0`]$K0,%0"0`)`.````!\`@``AB]RQY8OIB^V+\8OUB]OW.8O
M;]D,/")/PV&<,>A_$F'S:$,8$F(E&`#B4AAITO-E81@(=?-F\V0$=@,"#'1F
MT-AX9M/.!6;04V8#`\X$9=#.`1!A&"%VC1-J`M`2`<X``J`,,?@```"NDA)A
MC50L,1J$0VH$=`/+&H!;T18T`H\#>I.@"0!9T0,!"$2,4P-G5]`R878,$B=6
MT5?0S#&-51$7S@$2%U71S#$3%P'A%S4"C5-A@*`$Y0A!^'%S8@E!$'($<P%Q
M"0`V9A!!8B+[CP1R`W4(14K;?#5*T@#ALVT2)<P]2-6C9A(OTF0#`LPU""!!
MB471PV"^!/-M`P$0?4/2`VI#U--E`P+,-`@@.(E!T<-@`P&^!$#2`P()`,-A
MG#$288]3$F`P,`#C`.!(CZ-@&'\F3_9N]FWV;/9K]FKV:0L`]F@VT0,!"0`#
M9"S02"0SC48,,],#`PD``M`2`<X``Z`,,0D`^````!)A+)`,,:-@<:\2@"O3
M`P/29+FO"0`JWLP^XF1()`6-TV4HT`,`"0"\KPD`)M,GU`,#S#0"+@@@M(T#
M9/&O"0`CTR30)-3.!0,#S#2-KPA%(M(#`@'D(M$#`0D`X`*0!23F`0`(`0``
MBO___^@```!:.@````$```P!``#___\_7/[__R0!``!85O[__/___UQ6_O\H
M`0``F/G__YPA_O_L_/__3`(``-13_O\<^?__8OO__\3Z__^4^___!OK__R`!
M``!((```N`$``'!3_O_X_/__$`$``)A5_O^>^___>/S__P#N]F7S9D8OYB\$
MU`#G!-$+00D``]$+00D`"0````````````````#&+PG'"-P)U`P\"=',-,PQ
M(D]`,06)!]#.`1@A`8D+00D`)D\+`/9L4.4!````````````\````,8O#<<,
MW`W4##P-U<PTS#5(-2%%(45380!!`.$>-2%%6"4&C2)/!]#.`1@A`8D+00D`
M)D\+`/9L".4!````````````]````(8O#L?&+PW<#=@B3PP\PV",`1@A#8L+
MT,X!&"$#B0K1"M`#`<X$"M`#``D``>'#8!0()D_V;`L`]F@)`+SD`0`8`0``
M!`$```KZ___L____5/___P'1(P$)``D`7O___X8O)L>6+Z8OQB\DW`P\)-#.
M`1)JJ"H_B4!@""`"C3V()8]#80#IHF,X(QJ)HV<)`)@I,VA#8`R-DV8$81@A
M!8V$8A`R`H\<81!&]HLL8A`R`XN38#P`/8@2B7%3."/GCP1W]FPS8/9J]FD+
M`/9H`7$3:11@""`!C3V(^8O3KT@YJ#?V;"%']FHA1Q@`<B6>,_9I,V`+`/9H
MXZ\`X_SC`0#D````AB\?QY8O0VBF+[8OQB\<W!S:(D\,/!S3PV&L,9!_$F'S
M:3!Y$F(O&0#B`P/S90@@$(_T4172*2$ADB`Q`XD4TB`Q"8_#81/1`N4#`8-D
M""`!H"D``.##8:PQ$F&?4A)C(#,`X@#C!XMP?R9/]FSV:_9J]FD+`/9H!]$#
M`0D``$!TXP$`"`$``#[W__\`\````*```"K[___&^?__AB]>QY8O2"2F+T-I
MMB_&+]8O6MSF+UK=##PB3\-AW#&(?Q)A\VLX>Q)B+QL`X@2-PV%`81@A%(O#
M8=PQ$F&_4Q)@,#``XP#@`8F3H`D`>'\F3_9N]FWV;/9K]FKV:0L`]FA(TP,#
M"0`((.6-`VI&TP,#HV0((%N-`V@3>(!@+H@$BX&$""#RB8!@+HA8C9-@`\A?
MCY-D`.)&82PA_(O\=$1A&"$)C1@`1&$8(06-&`!$81@A_^$:-!@`@V":-`/(
M3H^#80#C%F(\(OR+_'$48B@B!HD48B@B`XD48B@B_^(J,8@Q&``>-"C1`P$)
M`"C2`VXHU__F@1\!Y<PW`V22+P,"\V@DTPAXXV0#`X-E_X@&C>-D(=*$42DA
M+I(@,22)']$#`0D`'](#`N-DGZ\)`!W1`P&C9!W2`P*39'VOPV&!A"Z(I(^3
M8(*$"""/C9-@GZ\#R$1A&"&OC1@`^Z]$811B*"*]B?RO%&(1T`,`"0#9KPD`
M#]$#`0D``$#<X0$`"`$``*SZ__\`^/__<O7__VCY__\04_[_8OC__P#P``#6
M^/__7/G__];T__]X]?__D/[__R[X__^&+XG'EB^F+[8O0VO&+]8OA=SF+X78
M##PB3\-AC#$28>Q_4&#S:A)B)!H`X@#A/8A38!XP`\C4>@*-`VV1H-1AUF$L
M(?R+_'W481@A!HG481@A`XG481@A_^$:/737&``*/0-I\V6S9`,'#'4((`*/
M`7E\H,-@`\@"C0-AQ:`48@#C%F(\(OR+_'$48B@B"8T8`!1B*"(%C1@`%&(H
M(O_B*C$8``HQ%CT!B96@`V&N4F#3"$*P8`@@`HT]B`*/LV&IH`#D`7$)`!-D
M%&`((`&-/8CYB[@TPV`^`5?3`GT2;MPT$A\L/@,#(B\"+@@@\E$DC?)B$F$C
M8+-D'@%$8#V($(T`(0@@#8T38@*@`7(]B`B)`70C84-@\'`/A``B""#UCP%R
M/>(@(0&@`7$!>9-@\'`/A``A""#XCP%QPV&,,1)AKU,29C`V`.,`YFB+%'\F
M3_9N]FWV;/9K]FKV:0L`]F@8(0&+>:\)`/JOU&$QTSX!$F=R81@A3XUS80#N
M!'$68N-E*"+[CP%^`W4(12O1S#$28B@B*X]S9`'B4V0B(2?1<A\#`3$?""#'
MC?)7<V4DU^-B"$(B+R-F`P<#9/%3`V'#8#X'$B?R8N-G"$=\,>X:`.=NKW$1
M`J"38`%YDV#P<`^$`"$((/B/`7&GK\-A%=$#`3$?\5,#8<-@&"$^`IR-$B+C
M8N"O"$(H(@&+2:\8`/JO%&)?K\-@".6WKP#N"M<#!PD`"0!XWP$`"`$``)S\
M___D````OO/__QP!````\___YO/__U;T___*]?__AB\RQY8O0VFF+U-JMB_&
M+]8OYB]7D2W<(D\MW@P\&#]2G2S3PV'L,2O4$F'\/4R6S#028B\=`.(#`_-E
M%4`&CP-H_W#\`1@A)(\((""+(],"T!(!S@`#H`PQ"0#X````HV829`,#DV7#
M8>PQ$F'?4A)C(#,`X@#C(HLDEWP_)D_V;O9M]FSV:_9J]FD+`/9H`V@)`!+1
M+^6#9@,!\V0((-6-@V</T@+0$@'.``*@##'X````$F3S9@,"DV75K\-A"=$#
M`0D`!!#$#_\/A-X!``@!``!0\___&%/^_]#R__\*\___(/3__]KT__^&+Q/'
MQB\2W!+1##P2UP+0$@C.``*@##CX````(D\/T/A_#]7,-\X&@F0#`<PU`.$,
MUQ$?#-',-PS6#=5R+\PV@F0#`<PU"'\F3_9L"P#V:!3>`0#6]?__V)/^__P`
M```H4_[_5%;^_P+S__^@-_[_1%/^_\8O#,<+W")/##P+UP+0$@'.``.@##$)
M`/@````29`?1S#<'T`?5S@8#`<PU)D\+`/9L"0"\W0$`V)/^_V3U___\````
M*%/^_X8O+,>6+Z8OMB_&+TV1*=PB3RG:##P8/RC31YG#8:PQ\V@28?PY"'A!
MFQ)B+QD`X@,#_#LBT8-D(M<!Y<PQ-Y81'\PW(-$#`0(O(-.#9#"6`P.S91%`
M(X\#:!W1`V0#`0%T""`)C0-A&M*#9K-E`P(#9`#B`V&#8"0!PV*L,B)BGU,B
M9S`W`.,`YPN/$V`,EWP_)D_V;/9K]FKV:0L`]FCKKP#A#-`#``D`%"#4'PP0
M`1``$/3<`0`(`0``.//__VA3_O]<4_[_<O3__Y#Q__].\/__*O7__T[S__\%
MT0;'QB\%W")/##P#`0D`)D\+`/9L"0`4____L-P!`(8O5L>6+T-HIB]3:K8O
MQB_6+^8O(D^;D5#<&#^9D5#3##S\,4_2%!_#89.7/#$28?-M3=3\-Q1]$F`!
M%P#@S#0#`M-E2=,OY0-I`P.#9`@@'HE'UX-E1]0#!\PT@V!`T\-A=Y<\,1)A
M_#=Q4A)C(#,`X@#C`8E$H0D`:9=\/R9/]F[V;?9L]FOV:O9I"P#V:#G1HV0Y
MV@,!"0`YT@-DHV4#`LPU""#4C0-C-M(P85*;S#(C'Q@A3YX"C_P[Q:"8*9@I
M"0`>C9-@.R`#R)-E`HTS9]V@=&%V8E9@`.8C80DB;"("CQ`PSZ#\=?6-=F((
M8!AA"6`980A@&&$0,`./,V"3H`D`,V`#R`*-,V&SH!1B`.(69RPG_(O\<11B
M*"()C1@`%&(H(@6-&``48B@B_^(J,1@`$V?^<3-F.C<!=A(S,V%\,1-B`.4C
MCV@R/*"#8(001!!\$(``_P\)`%#;`0`(`0``T/?__W!3_O_*\O__L/K__WQ3
M_O_:\/__C%/^_[CO__^04_[_$$("CU`ADZ`S8/]Q$&`OB/:-,V`#R`*-,V=]
MH'1A`.%V8APB_(O\=W1A&"$&B71A&"$#B71A&"'_X1HW:#>#8`/(28^#80#B
M%F8L)OR+_'$48B@B"8T8`!1B*"(%C1@`%&(H(O_B*C$8`(HQ&`!^,>8Q'HT!
MY4/1\U>S9,PQ?Y81'T'1,B\#`8(?0-+390,"LV0((`6+/M+442DA/=(@,5N)
M/=(`Y*-E`P+,-0@@`H\#8PJO"0`P81@A`8D^KY@IF"D"B9!@+H@MB333@V`#
MR`'GS#.WC8-A%&()`"@BQ(T8`!1B*"+`C1@`]Z\48B@B`HD48B@B`8M8KQ@`
M]Z\48OQW"0!T80D`&"$#C51@$##XC1QA+:\,8!@ACXET81@AC(GYKW1AD80(
M(+J)S:\)``/("(\S9P#A=F(<(@&+<Z_\=_JO=F)T81@A`HET81@A`8MTKV@W
M]Z]T81'3`>4#`[-D"""=BP_7LV4/U`,'S#0.T0,!LV2NK@D`#=<#!PD``!`)
M`)A3_O^N\?__JO#__P#P````@```*.[__VQ3_O]&\?__%/C__WQ3_O]V[O__
M].___X8O"L<*T2_EQB\(W")/##P#`4-H""`!B0-H`7@%T0,!@V0F3_9L"P#V
M:`D`1-D!`,3P__\6[O__AB]$QY8O2"2F+[8OQB]^D4#<(D]`V@P\&#]YF<-A
MK#$28?PY$F(O&0#B4XE`81@A4(E#8`/(58]#9@#B9F$L(?R+_'9D81@A!HED
M81@A`XED81@A_^$:-EN1&`!C:$@V2C@6-B2-`.`LT4-E\V0#`?-K@V'_<?PQ
M$C\-C1@`\V&,,1-B`.,"H/HR!8TP(?]Q$&`OB/F-$$(ATB_E`P+S9`@@*XVV
M,!N-`.$>T0,!\V3#8:PQ$F&?4A)C(#,`X@#C(HLDEWP_)D_V;/9K]FKV:0L`
M]F@4TQ74`P/,-.FOPV'CKQ`@9&$8(?R/8V@1D4@V2C@6-KB/`.#;K\-A#-,+
MU`,#S#35K\-A"M`#``D`!!#$#P`0)-@!``@!``"Z\/__`/#__U#M__\D[?__
M;%/^__SL__]Z[O__AB^EQY8OIB^V+\8OUB^BW.8OHMT,/")/H=K#8:';W#'X
M?Q)A\VG,.LAY$F(O&0#BS#L)`)S3\V4#`Z-D""`0B;)AGE(280A"+#$14B@B
M\8TB(01Q$5(B(2@B^X\$<>FO"0"2VH_;S#K,.PD`D-'S90,!HV0((!")LF&>
M4A)A"$(L,1%2*"+QC2(A!'$14B(A*"+[CP1QZ:\)`(;:@=O,.LP["0"$TO-E
M`P*C9`@@$(FR89Y2$F$(0BPQ$5(H(O&-(B$$<1%2(B$H(ON/!''IKPD`>MIS
MV\PZS#L)`'C3\V4#`Z-D""`0B;)AGE(280A"+#$14B@B\8TB(01Q$5(B(2@B
M^X\$<>FO"0!NVV7:LV[,/LPZ;-'S90,!XV0((!")HF&>4A)A"$(L,1%2*"+Q
MC2(A!'$14B(A*"+[CP1QZ:\)`&+:5][,.LP^"0!@TO-E`P*C9`@@$(GB89Y2
M$F$(0BPQ$5(H(O&-(B$$<1%2(B$H(ON/!''IKPD`5MY)VLP^S#H)`%33\V4#
M`^-D""`0B:)AGE(280A"+#$14B@B\8TB(01Q$5(B(2@B^X\$<>FO"0!*WCO:
MS#[,.@D`2-'S90,!XV0((!")HF&>4A)A"$(L,1%2*"+QC2(A!'$14B(A*"+[
MCP1QZ:\)`#[>+=K,/LPZ"0`\TO-E`P+C9`@@$(FB89Y2$F$(0BPQ$5(H(O&-
M(B$$<1%2(B$H(ON/!''IKPD`,MH?WLPZS#X)`##3\V4#`Z-D""`0B>)AGE(2
M80A"+#$14B@B\8TB(01Q$5(B(2@B^X\$<>FO"0`FVA'>S#K,/@D`)-'S90,!
MHV0(($6-\V7B89Y2$F$(0BPQ$5(H(O"-(B$$<0D`$5(B(2@B^X\$<>>O"0`)
M`&C5`0`(`0``G%/^_^0````L\___J%/^__3R__^P4_[_O/+__[Q3_O^$\O__
MQ%/^_TSR___44_[_%/+__W!3_O_<\?__X%/^_Z3Q___L4_[_;/'___A3_O\T
M\?__?%/^__SP__\ETB;4`P+,-`@@!(T#9233)-0#`\PT)-'S9234`P',-`@@
M!(T#92+2(M0#`LPT(M/S92+4`P/,-`@@'(T#92#1(-0#`<PTPV'<,1)AGU(2
M8R`S`.(`XQR/LV0;U1O2S#3,-0A_)D_V;O9M]FSV:_9J]FDC`O9H%M+S91;4
M`P+,-`@@X(T#9133%-0#`\PTVZ_#81/1`P$)`&3P__\$5/[_3O/__^Q3_O],
M\/__&%3^_S;S__\L5/[_-/#__SA4_O\>\___<%/^_UQ4_O_N\O__[.___TA4
M_O_6\O__X%/^_[SJ__^&+QG'EB_&+Q?<&-DB3PP\%]/#89PQ^'\281;4\VCS
M91)B(1@`X@,#S#0((!>-R'@`8#"(*0$(("D"$V`K(`'*PV&<,1)ACU(28R`S
M`.(`XP>+"'\F3_9L]FD+`/9H[Z\`X`71`P$)`+C3`0`(`0``7N___^!3_O\(
MZO__AB_XXI8O*<>F+[8OQB\B3Y!_)MSS81AQ*2$38AAR:1$$<GH1##Q8$1-C
MJO(@<[OR0V838A!R!'(=UXKRF_(38@AR!'(;T&KR!'%[\L-B?#)*\2)G\V);
M\3!R.!)R95\2`.4U$@'E'I,7$BQQ_#,6$CD2S@$E6B9;\V),<@[7(F@A61)D
M\V%8<301HB&Q$8(1DQ$T'Z(OL1^"'P,'DQ\'T0*4`P$)`(@`_P`)`/C2`0`(
M`0``%`$``'KG__]NZ/__AB]/QY8O`.6F+[8O_^O&+]8O0VWF+R)/2M%)W$K2
M&#]*U@P\_#)*UR(OPV%)TFPQ$F'\-P#F$F`$%P#@`P("YP@`$VH..__ALV8>
M.J-A`$$:,1-G"``I1WXV;6((`'HR`.,`X3HQ"``J.QHZ$4I7C__@.=GS:`1X
MS#D)`#?2`.>S9:-F`P+39`-B$V#_B$F-(V`STH-E,]8#`M-D_XA'C0?A%C`Q
MC_AP@VX,/H(^`XDKH`D`@CXHBRO7".:390,'XV0((/:/_WX!?N-AB#$7,!-@
M.C,(`#-AOC"N,1O3PV(;UCPR(F+\-F17(F-P,P#G`.,ABQ/7?#\F3_9N]FWV
M;/9K]FKV:0L`]F@8T/_A#CL>.J-@_XBQBQ31$#NNC__@W*__X?^(M(L1T1+4
M`P',-!'3$M0#`\PT$=8#!@D`"0"DT0$`$``!`-#_```(`0``_/\``.3E___P
M____G.7__R3I__\(``$``NC__P``__\0_O__8%3^_PC^__]P5/[_]N?__PC1
M"<?&+PC<(D\,/`,!"0`&T0,!`V0((`")`F`F3PL`]FP)`+#C__\XT0$`<N/_
M_X8O3\>6+T-IIB^V+\8OUB]+W.8O2]T,/")/PV'<,>Q_$F'S:TC:$F(D&P#B
M1]'S9:-D#'4#`<PT""#4>P2-`V@`81@A%X^38,-AW#$28;]2$F,@,P#B`.-K
MCZ-D/-',-)-E%'\F3_9N]FWV;/9K]FKV:2,!]F@#R%"/DV0`XD9A+"'\B_QT
M1&$8(0F-&`!$81@A!8T8`$1A&"'_X1HT&`"#8)HT`\@_CX-A`.,68CPB_(O\
M<11B*"(&B11B*"(#B11B*"+_XBHQB#$8`!XT(=$#`0D`(-'_YB#2`>4@U\PQ
M$1\#;H(?S#>2+P,"`V3#8=PQ$F&_4Q)@,#``XP#@&X^C9!C2S#3C911_)D_V
M;O9M]FSV:_9J]FDC`O9H1&$8(;Z-&`#[KT1A%&(H(LR)_*\48@W0`P`)``S1
M`P$)``D`\,\!``@!``!\5/[_8.S__QKO__]DX___C%/^_U;G__^04_[_=.[_
M_TCF__]"YO__AB])QY8OIB^V+\8OUB_F+T7<(D]%UPP\A']^DL-A?#&$?Q)A
M>I#\,B<?\VL28B8/`.)TFC[1)'O\.C[3S#%OF!(JS#,\T?PX2!^S9<PQ(AH1
M&F:1.=3\,3$1.=,E$<PS,A$XT\PS,Q$WT\PS-!$WT<PQ$B@VT<PQ$1@B&#72
M`P+,-`@@!(D`81@A`8E-H0-D,=$#`0D`,=(#`@-D""`#B0)NZ"X"C^-@%Z&&
M9`/(`HWC9"NA1&$`X49B'"+\B_QT1&$8(0:)1&$8(0.)1&$8(?_A&C0BUQ@`
MZC3C:1@``7D#!TXTX&$8(1*-`V@=WI-M@VG,/AQA"0"39!(O_^8:T0'EXV<#
M`0)YU&$8(?2/'&$(F1;4_#DNH,PTN`#T`)``G`"H`*P`"0"8S@$`"`$``)14
M_O\P5/[_;%/^_W!3_O^<5/[_=%/^_Z14_O^H5/[_L%3^_Z;J__^*X?__3.'_
M_^3A__^\5/[_S.7__RQ4_O^69$@D%(EST@,"LV4((/>-`VX`81@A\XEOTP,#
M`V0((.Z);M<#!^-D""`5CP-N"0"F;N@N$8T`X>!A&"$!BZN@`.YGT0,!XV0(
M(/&)9=(#`N-D""#LC0-N`.'C:99B'"+\B_QYE&$8(0F-&`"481@A!8T8`)1A
M&"'_X1HY&```XNHY@V$68RPC_(O\<11B*"()C1@`%&(H(@6-&``48B@B_^(J
M,1@`D).*,4_7'#D\.0,'DV1-T?_F3=<!Y<PQ`VH2'\PW2]&#'\PQXB\1'TK1
M`P$#9$G2>94#`J-D_X@(BT?3`P,)``)B(V`1B`&)6Z'#8$37LV4#!Z-D""`(
MCP-H0=*T42DA8I(@,0&+DJ`)`#[0`>4^T\X!^%(^UJ(O(F?,-@,#$F0`Z3O2
MPV%0DRPQ$F'\,SY7$F!P,`#G`.`"C9-@*Z()`'Q_?'\F3_9N]FWV;/9K]FKV
M:0L`]F@OTP,#"0`((""/`.&&9$@D"XDLT@,"LV4((/>-`V0`81@A[8N&9$@D
M\XLGT2?9`P$-Y!@`4^'..?*N`VA?KP#A&"$!B^"N"0#ZKT1A`VX#9$9B'"(!
MB\VN_'3ZKT9B'-,#`P8?&]<#!_94KZ\#:00$P`$`0+P`"0"LZ?__/NK___#B
M__\4ZO__QN+__Z3@___05/[_Q%3^_YA3_O^0Y/__'./__[[B___.X/__`/``
M`!0!``#ZW___%%7^_P@!``"VX?__1.C__\K?__^,5/[_8/O__U+A__]DT0,!
MMEX`/@6+P9*T42DAP7(@,0&)8:\)`%_7`P>39%[1LV5>U`-I`P',-`@@!XT#
M95S7^%,#!S)D""`"CP-N\*#X4N-@`\@"C>-AV*`48@#B%F,L(_R+_'$48B@B
M"8T8`!1B*"(%C1@`%&(H(O_B*C$8``/BZC$F,2>/$V#\<$G7[#`#R`*-S#?#
MH'1B=F8&8P#E8V(Y)EPF`H\@,[6@_'#UC79F.&,H8CEC*6(X8RAB(#,*CQ-@
M!(@$B>PQ^W$08"^(`HL%H?A1"0`WT;-E-]W39`,!S#0((`2)`&`((`&-,(@!
MBY^@`.4RTM-D,M7,-#+;,MT#`LPU,M/,.TB>`P/,/3#1_^8PUP'ES#&S'Q$?
MS#<NT9-D`A\#`:(O%J`)`"S1`P$)``)@$8@5BRK2`P(!>"31_^8HTP'ES#&T
M'X,?TV<"'Y-D$1\#`Z(O)-?C90,'DV3_B..)(M(#`J-D(=.392'4`P/,-"'7
M`P>39,"N"0`?T2#3`>4A'QX!^%(>UJ(O(F?,-@,#$F2RK@#I_P'``7;>__\$
MW___6.?__VA5_O\V[___<%7^_ZSF___@4_[_@NG__UQ4_O]45O[_K%7^_]S@
M__^84_[_G%7^_Q+B__](X/__K.#__^+A__]NX/__[.'__Q+I__]P4_[_?/G_
M_Q0!``!@W?__V%3^_R@B`8LVKQ@`^J\48OQW"0!T8@D`*"(#C01C(#/XC2QB
M1Z\\8PZO(FY5T@,"XV0((">-`VM3TP,#`V0102&/$VY1T_;E"`#_Y@XULV0>
M-@4?`P,`YX^1!N9,U[-D_#$6'P,'$V4&B/91`HWU4G^@"0`29T?3,#<$BQ*%
M?9,-83`Q`8DRKPD`SN4(`"XU0=+_YK-D[C9QF`,"`.<_T_PX*.:#90,#LV0H
MB&&/`.!FD3O7_^;\,9-D&(#,-SG1@A_,,:(O$Q\WT<PQ$1\WT0,!`>5#KPD`
M$5(H(C.-(V`#R#*/(V$`XQ9G/"?\B_QQ%&,X(PF-&``48S@C!8T8`!1C."/_
MXSHQ&``#XRHQ-C$9C_QQ)M<C8!PP`\@=C\PW=F8&8P#E8V$Y)EPF$XT0,_>-
M=F8X8QAA.6,983AC&&$0,P"+(V[#K@D`%&,X(]R-&`#[KQ1C_'#\=W1A&"$#
MC01C$#/YC1QAZJ\\8Q'1`P$)`!'0$=0#`,PTP`!(1<@`Z``)`#KA___^]O__
M"-W__Y3@__\`0T%#PMS__U+@__^,5?[_5%;^_YA3_O]@X/__>%7^__[>__\"
M]?__@%7^_X8O<L>6+Z8OMB_&+V_<<-K6+PP\(D_#8:PQ$F'X?_-I;-,28B$9
M`.)KU`+0$@'.``*@##'X````$FO,-/-ELV%@<1B$R'D#`QF`""`%C0-A`&`Q
MB`&+FJ`1A&#0`P`)``+0$@'.``.@##$)`/@````2:UO1LV1;U0/G`>8#`<PU
M""`6C0-K6-(#40+0$@W.``*@##WX````5-829=)D`P+,-K-14M,295)1."$!
MB7R@"0!0T@+0$@W.``.@##T)`/@```!,U0/GTF0!Y@,"S#4((`Z-`VM)T_-E
M2=0#`\PTLU$((`-F6(T29$;00V4#`-)D`M`2"\X``J`,._@```!!T@'FLFU!
MU=-D`P+,-4#3`V5`UM-D`P/,-K)A`.`^U/-E8'$]VQF`S#0]T0,!S#L"*P@@
M'XT#:#K11I4#`8-D`>$#8@%R%C(#CP-G$8@QC\-@PV&L,1)AGU(28R`S`.(`
MXR^+"'\F3_9M]FSV:_9J]FD+`/9H+-(LT`,"S@0"*P@@V8\#:"K3*M0#`\PT
M""`!BVZO"0!@KPD`)-#.`1)E)=$#`0D`I*\)`"31`P'29'^O"0`=T2+4@V8>
M`1)E(=$#`<PT(-`#``D`P`&4Q@$`"`$``'[C___$4_[_`/#__ZS;___`5?[_
MIMO__\15_O\``$``7-O__\Q5_O_HXO__?%/^_U;;___.V?__T%7^_R[;___H
M5?[_<%/^_R`!``"8XO__R-S__R+W__\D`0``DMW___!5_O]JY___Y-S__Q16
M_O]<W?__YMS__X8O0L>6+T-HIB^V+\8O/]P_VB)/##P_T\-AK#'X?Q)A/=3S
M:?-E$F(A&0#B`P/,-`@@#HW(>0!@""`I`3"(*0(K(15!!8V(*`2-PV&`81@A
M$(O#8:PQ$F&?4A)C(#,`X@#C3(L(?R9/]FSV:_9J]FD+`/9H*=$#`8-D*=(O
MY0-K`P(#9`@@`8D#:P%[)=,#`[-D)=(#8P!AS#(@8`@@&(T`,1:/#&`QA`-A
M(80((!"-`#$.CPQ@,H0#82*$""`(C0`Q!H\,8#.$`V$CA`@@`(D,8!QA`#&]
MC\-AK#$289]2$F,@,P#B`.,,CX-D#]$(?R9/]FSV:_9J]FDC`?9H#-`#``D`
M"]`#``D`"0`(Q0$`"`$``$SA___@4_[_8NS___C<__]*VO__T%3^_[[A__]@
MV___6MO__X8O,L>6+Z8OMB_&+]8OYB\B3U61+=P8/U.1+=,,/$#@+-C\,/-F
M_#%`$!00PV%)E#PQ$F%4=@!7_#0GT!)E5A0`Y3AW;Q\`Y&-C".5R81!%<5((
M=QAA01,982-F&&%#$Q(C*48C81E!&4:)(6LA(V8H1AA&&$)K(0DB*R$2$^6/
M$',@D$#J_#H>EP-B.'#\,J5;+%E4YBI3_#<K4?PV+5X#8J-@_#((5!!V(F4A
M70=23A]S9'$00."F6IP?$*`M']@"F`*\`I0`U``)`!#$`0`(`0```/\`````
M_P"='XX?8FEC8BQ785@(=BU2FB<Z)_Q3BB*Z)_U;&B)Z'ZHB^E$K'U-J^E+3
M9P#MK!\`0M$4`$$C9?M1_EHD01LEXV%2)!!`"'3:CW-N0.#_WOX)!>C^"N7G
M_@T(`/X`DFD#4*%:!A]`X/X!_@,44?X"-E,E4A4?HV&9'XU!,Q^38WU#DV=`
MZ?X$C4?^!1LC_@;\.20?<V([(I53Y>E85=)=[C-'5`@`:59>,]<?"`!"'SXR
M41\(`/55'N1B+^7FJ!\`[?-:]U"J):-G"24#85HG`V-^,O97"4'Y54U'"`!-
M0_-4>R'U5SLA^5,3:!HG0.#U45DG(V7\,'HA!U=M1>XW"``>ZDXW(V0(``E#
M?C$%YP@`?43Y5T-F6R9N,?A6K4<(`*U&]5IK(Q-K>R.#9T#F,V4Z)RDG_#9S
M8VE7BB/EYNXW"``%X*XW$VH(`&U*?C,%YP@`?4LC9[-FJR8>Z@E'K4)[(E-G
M;C,C:BHG"`!`YADG_#9S8FM76B(>YNXW>A\(`/I7CC<S:`@`G4A^,A-G;4$S
M:0E'"`![(:-G&B<Y)PU)DV"+(!-H<V%`Y_PW#C)]5@@`JB'N-B-D;!_EX'Y6
M,V<)1]XV:A\(`/Q6#40C8%XV"``%Y6XQ'N8(`&U#>R.#9SHG*2==0`-E2R4S
M9'-C0.?\-UXQ?U4(`(HC[C43:UH?"`#Z5^7FKC<3:@@`;4I^,P7G"`!]2R-G
MLV:K)A[J"4>M0GLB0V=N,R-E*B<(`'SF,VD9)S-J_#9S8F)72B+N-WH?"`#Z
M5XXW"`#EZ'XR!><(`(U)?4H39Z-HFRB.,A[H"``)1R-@C4%[(5-G&B<3:#DG
M<V%\Y_PW=%9:(>7J[C9L'ZU`=58S9PE'(VK>-FH?"`#\5DXV"``%Y&XQ'N8(
M`&U#>R-4YTU*_#>C9$!W"R0`ZDC@I@].,7!6"``S8(-C[C83:@HC"`!>-A-K
M*2,(`#-DBB1N-"-CY>4(``7F74IM2[-FJR8>Z@E#K4).-CLB<E,(`"-E[C,#
M8@@`6B*.,V-I&2((`"-D"B0^-&-JY>,38@7H"``]28U*HV.;(Q[I"4*=04#J
M*R'\.@#B3C,C&G12"``39%-A[C(S:4HA"``.,C-J:2$(`!-H6B@N.&-AY>`(
M``7B#4DM2J-BFR*.,A[H"``)02-IC48C:ALF0V%C8&HA=E8Y(1-H2BCN-C-A
M"``)05XV"`#EY6XX!>8(`%U);4JC9ILFCC8>Z`@`C4-C:1LC`V$S93HA>%,I
M(1-H"BCN,V-J"``C84XS"``%Y#XXY>,(`#U)34JC8YLCCC,>Z`@`"4$S:8U"
M,VH;(E-A(V0J(7I2:2$3:%HH[C)C80@`"4$.,@@`!>`N..7B"``M20U*HV*;
M(HXR'N@(`(U&(V@;)D-A8V!J(7Q6.2$3:DHJ[C8S80@`"4%>-@@`!>6N-N7J
M"`"M2"-J74JC9XLG;C<>Y@.@"``)`)EY@EIM0QLC`V$Z(3-F*2$C8Q-J5.'\
M,7AQ$FL**@7HHV'N.W-J"``)0TX["`#EY+XQ<VM-2@@`C4NS:*LH'NJM0CLB
MCC$C:&-BBB)Y(@@`(V/^DFHC$VG\,A-K)E3EY>XT3!\G5'-B"4+>-$H?"`#\
M5`XT"`#EX$XS!>0(``U)34NS8)L@'NF=1RLG<V2#9THG&2=S8MR7#C/\-P@`
M>%F*(C-K[CF<'WE9$V<)1]XYFA\(`/Q9!>UN.0@`!>:>,C-I;4L(`%U)LV6;
M)1[IG4%[(1-F0V%J(3DA$VFYD5XR_#$(`!I72BDC:B-K[C=Z'P@`^E$S9PE'
MCC$(`.7H'CD%X0@`C4H=2Q[HLV&-0ZLA,VB>,9V9>RAC8XHC"``I(Q-@_#DS
M:IQ3:BJC:>7J[C,(`*U`3C,3:MU*"`"C9`LD'N`^.2-C#4((``E#0]`[(H-C
M*B,S9WR33CG\,P@`/EH:)^7EDVL..A-C"`#=2VXZ"``>YJXWDVI=2K-EJR5I
MF@E#"`!M09-F_#I>-SLAH%,(`.7M#C,C:@@`&BJ.,W-K!>6C:%U+<VJ:*`@`
MW4J.,[-HJRA.F@@`"4G\.HXSHE4>Z`@`#C4C:HU&"`!K*5-BKC(3:IHJ,VL>
MY:-H,VK=2@7M<V9Z*`@`W4M=1XXRLVBK*'-J+Y<(`(XRDVC\-P@`<F4)1FLJ
M(VL.-0@`JB@>-8-FY><C:#HF"`!]2!R7W4LS86XULV:+)@@`'NBC:_PW"4&-
M0VXU&R-P40@`.BL.,5-M"`#EYIXQLVD(`"HI!Z">,;P`_``,`10!"0"AZ]EN
M4VL%Z0@`;4N=3=-F'NV[)C-K'C8C8=U""``)06-M&R)R42HK#C$(`.7IKC&S
M:@@`6BJN,6-K!>H(`)U+K4W3:1[MNRDC:QXY4V'=10@`"4&3;1LE=%%:*PXQ
MLVH(`&HJ/C&3:P@`Y>BN,6-C!>H(`(U+K4W3:+LH'CAV41[M"``.,5-K"4,(
M`-U&@VT[)BXQDV)J*P@`LVJ:*JXQ@VOEXP@`!>H]2ZU-TV.[(QXS>%$>[0@`
M#C%C:PE""`#=23-M*RE>,8-EFBL(`+-JBBJN,3-KY>((``7J+4NM3=-BNR(>
M,GI1'NT(``XQDVL)10@`W4@C;5LH;C$S9HHK"`"S:CHJKC$C:^7E"``%ZEU+
M?%6M32-GTVJ[*JXQ@VH>[0@`#C43:PE&"`#=0VLCGC4Z*@@`Y>:C:2HI$VK=
M0IXU;4HC9@7I_I*=2P@`"4>S:?PRJRF#:IXU>R8B9P@`Y>T.-U-K"`!S:*XX
M,VIJ*@@`!>>C:1HI4VJ>.!-BW4H(`'U+X9>S::LIGCAC:Q[I"`#\-PE"G4$3
M:2LI<%*:*[-J6BH.,H-K"`#=2SXR@VT%XP@`KC)383U-"`#3:KLJKC)R4Q[J
M"``.,Y-K"4$(`*U%&R6#86XS6BL(`.7MLVH%YB-KBBJN,]U+(VUM30@`TVJ[
M*JXS4VL>Z@@`"4$C9JU(&RAT48HK#C&S:@@`*BJ>,3-KY>T(``7IKC'=2S-M
MG4T(`--JNRJN,8-K'NH(`*U"(VEV4@E&#C)K*0@`7C(S9IHK"`#E[;-J!>43
M:SHJKC+=2Q-M74T(`--JNRJN,I-K'NH(`*U#,V5X4PE&#C-K)0@`CC,39EHK
M"`#E[;-J!>@C:QHJKC/=2R-MC4T(`--JNRJN,U-K'NH(``E&(VBM06LA>E8:
M*PXVLVH(`"HJGC8S:^7M"``%Z:XVW4LS;9U-"`#3:KLJKC8>Z@@`"4AC:ZU"
M$VJ+(GQ8*BJ#9PXW"`#E[5XWHVD%Z`@`.BEC:IXW,V7=2@@`C4NS::LIGC<>
MZ0@`"46=0W-I6R,>E3-HY>W\-5)C!>5=20XS(V`(`(H@'C,#9`@`:B1.,W-@
MY>1C84U`DV0>Z0@`"R0)09U&3C,$E`2@&R9,`50!C`&4`8-A:R$(`/PT8V5Y
M(8-F`.`3:@\?629`4&LJ[=$>YC-I'C`(`"-AY>(.,2U)<V)M1P@`"4)39BLG
M!>"N,3-J>R8(``U*.2:C8)L@X=H.,6-B0E8(`%-I>2FN-A-J"`";(HXV$VD(
M`-U);C)S8`7F"`!M2C-GHVB;*(XRU=T>Z`@`C4,#:`E'`VD[)Q-F>R@9*(-C
M1%AY*=XX(VT(`)LC7C@C:0@`!>6.,^7H"`"-25U-<V73:)LHCC,>Z`@`C48S
M:PE!:R$3:'-ABR$I(8DE$VU&45LMOM7EYFU+(V9>,0@`'N4.,0E&"`!=0FLB
M@V8%X"-EWC&#8C-M6R(-30@`.2+38%DF(VV[(+'2#C%K+4A6"``%ZBXV$VMJ
M'P@`^E(%Z7XR"`#EY]XR$VVM30@`TVH>[7U+,V?=0PE'>R-39S-F4V-K([LJ
M&2-I)S-MKC)*4WLMG]<(`"-K?C,(`!-GCC,(``E'WC,C;9U-"`#3:1[MW4%C
M;7LA(V?EZ(U+$VAC88LANRDI(8DMGC,3:4Q1VRF/W0@`Y>0S8-XQC=T(`$U`
M7C$(``7EGC$S:5U)"`"39![I"4>=0GLB@V<+)"-@@V(+(CDB"2=.,2-D>R3^
MEP@`Y>7\-Q-J<F(S9PE'WC((`.7I;C(%Y@@`;4H#9DXR$V1=1*-E'NH(`*U#
M2R7GE'LC7C(S90-C6R/\-`@`&2,C;5DF,V=NTVLG0%8C:P7J/C9J'P@`^E,>
MYHXS"`#EZ#XW!>,(`#U-$V-M00E#.R%38Q-FC4M386LA*2'3:&DC$VV[*$)1
MCC<[+5W3"`!S:SXQ"`"=2PXQ(V,%X`@`WC%S;0U-"`#3:;LIGC$>Z0@`"4,3
M:YU".R)C8R-@8V(+(GDB"2,C;4[2.RU$4RXS<V((``E"7C,(`.7EWC,3;:U-
M"`#3:A[MW4<K)P-B74L#97LBNRIS:QDB>26N,R-J1E);*C_5"``%YS-H7C((
M`&XR"`#EYJXR,VIM2`@`?4H39Z-FBR8>Z`E'C4%[(1-HLV&+(6XRLV8Y(0@`
MB28394A1:R4OUN7G(VEN,0@`'N8.,2-@"`!]0%XQ,V<%Y0@`"4=M0WLC@V==
M29-E"R4S8(-C"R,I(PDG7C$S92'3>R5*5P@`!>83;3XW>A\(`/I3;4TC9PE'
MOC,3:P@`7C/EY0@`74O391[MW4(#;7LB$V<C9@-B:R*[)1DB:2TC:UXS3%+;
M*P_="`#EY-XR,VH(`$U*CC(+W07H"`"^,C-KC4L(`+-HJR@>Z@E'K4%[(6-G
MCC(3:&-ABR$Y(0@`!*"))\P!U`'<O!N/$VI[*OZ7!>0C:?PW<F$S9PE'WC$(
M`.7M#C$(`.7@KC$C:@U)"`!-2H-DHV";(![IG4,.,>>0>R.#9SLG,VG\,`@`
M*2<Y)'-C<-=+(P!4!>5^-"-G"``)1VXT"``>YDXS$V1M0@@`W403;5U->R+3
M94LEDV=>,R-EDV);(ADB"`!9)R-F8=)[)@)7,VTS:RXW$V((``E"CC<%Z`@`
MC4U^-M-HY><(`![M?4M8U]U!NR@K(5-BCC83:%-ABR$Y(0@`B2(3;2LM!%(S
M80E!?C)C:@@`(V>>-V-K'N((`-XWY>D(``7M+4.=2MU+2-T;([-IJRDS:H-C
MJR-I(V-AGC<S8@93"`"#::DIWC-S9`@`FR)>,W-I"``%Y2XSY>((`"U$.])=
M29-E2R5>,PA5'ND(`"XU,VT)00@`G48S;ALFHV&.-7-D:B$(`!-I>BE>.?E1
MY>4(``7H74V-3N-EVR6>-1[I"`"=1PI9"413:RXY4VU+)P@`KCEC9'HD"`!#
M:#HHGC@S9.7J"``%Z:U+G4W3:KLJKC@>Z@@`"42#:ZU#8VI+(PQ4Y>U#8"XP
M"``#9JXV<VHZ*@@`!>"C:5HI@VJ>-E-DW4H(``U+LVFK*9XV<VH>Z0@`"41C
M:YU%2R44E/PT0F"#9`E$+C`(``-G'N"N-S-J6BH(`*-IBBD-2$LH!)0(H&-J
M#`(4`DP"5`+<O!N/UL%BRMU*!>V>-]U+"`#\-+-IJRDS:YXW0%D(`'-M+CD(
M`)-COC-3:XHK"`"S:FHJKC-S:P7J"`#EZ:U-G4O3:1[JNRF#:SXY8V.M1@@`
M"4,[)D)3:BLN,[-J"`!Z*EXSDVOE[0@`!>6N,]U+DVU=30@`'NK39;LE8VL^
M-7-CK4<(``E#.R=$4WHK+C.S:@@`FBJ.,U-KY>T(``7@DVBN,]U+4VT-30@`
MTV"[(#XP<VL>XP@`/4E&4PE(`VTN,XLI"`!N,U-HFBL(`+-J6BJN,P-KY>8(
M``7J;4NM3=-F'NV[)I-K/C938]U#"``S:DA3"4AC;2XSBRH(`'XS`V>J*P@`
MLV@**(XS8VOEY0@`!>A=2XU-8VC39;LE/C5*4Q[M"``N,Z-K"4<(`-U`4VU[
M()XS"BL(`+-I:BF>,U-K!>D(`)U-Y>=]2]-G'NV[)PE(W48^-_Z3BR9,6`@`
MY>0N.'-K"`#\,ZXX`VIJ*@@`HVE:*9XX<VH%Z0@`34I39)U+LVFK*9XX,FD(
M``E$+CEC:MU%"`!+)7-D#CF#:UHJ"``>XZ-@"42#:GH@/4=+)]*4#CGE[0@`
M!>#=2@U+_#2S8*L@0%,..5-K"`!Z*RXSLVH(`(HJ;C.3:P7@"`"N,]U+DVT-
M30@`'N;38+L@<VL^,(-C;4A"5@@`"4,N-@-M.R@(`%XVDV.**P@`LVJ:*JXV
M`VOEZ@@`!>6M2UU-TVJ[*JXV@VL>Z@@`K4D)0Y-E.R5$4UHK+C.S:@@`"BI^
M,V-KY>T(``7I`V>N,]U+8VV=30@`TVJ[*JXS4VL>Z@@`"4>M0'L@1E<**RXW
MLVH(`&HJCC<S:^7M"``%Z:XWW4LS;9U-"``>ZM-INRD#:WXY8V>M1@@`"4=[
M)DA7:BLN-[-J"``Z*EXWDVOE[0@`!>6N-]U+DVU=30@`'NC39;LE8VM^-3-G
MC4,(``E'4VU[(TI7.BLN-[-J"`":*@XW4VL(``7HKC?EZ@@`K4N3:HU-TV@>
M[;LH4VM^.)-GW4<(`'-@3%<)2H-I+C>K(`@`;C<S:@HJ"`#EY*-F!>I:)FXW
M@V:M20@`34:39&LD<V939]U'3#9S9!"7"4N[)&-M_#=C:W)E+C7W4@@`'C4S
M80@``.,#H%XQC`*4`LP"`V5*)0@`4V>*)WXQY>4(``7G?4T]EUU+TV5`[;LE
M7C'\/0@`T%TN-H-B"4(2+0@`8AU`YC$=_#8S'1[MW4A@5H-A*R'U4OPW\U@N
M,346"``4%HXT\5$(`$86'C`W%@@6PV$Y%@S6;#$28798$FF`.0#H`.D*BPV7
M?#\F3_9N]FWV;/9K]FKV:0L`]F@#V@,*"0"\`M@""`$``(C&__\4T17'QB\4
MW")/##P#`7SD$M(`XS$0`.,B(`-A$-)`<3,0`.,B$`_2-1``XR00#M(W$`#C
M)A`-TCD0`.,H$`#B*A`L$`#B.Q`]$"X1)D\+`/9L"0`DP___U*\!``$C16>)
MJ\WO_MRZF'94,A#PX=+#AB]%QY8O8V&F+PA!MB]#:L8O'#'6+U-MYB]C92)/
M/MP`15HU8VD,/$I0"`!+5`XQ4V,`XJQ6"$,F-*U7^']FCSPS`>`(``#D#C9.
M-RL:X^(:&I-A+4$(`#LA4V+CXZ-N;C&C:SU"'!I^,BT:0'[N5$@D,X\X>S_A
M%SD?C_KBDV,&X=-HP',M23(ODV,=2?]S,1_<.2'2@V5`YK-D`P)`>!_3`P.C
M9)`X](_Q4L#A\F-`?1<".2$</1H)/#D9T9-FTV4#`;-DGAX(?R9/]F[V;?9L
M]FOV:O9I"P#V:$MH0'B7.!*)$-&C:SA[@V:\-`,!TV7N4(PP0(CFCPX>"]*(
M.8P]`P*C9+>O/^'KKY-H%C"<CP'@EZ\(`*2N`0`0Q___.NK__^K&__^^QO__
MVNG__X8O2L>6+T-IIB]3:+8OQB_6+U-M(D]%W#A]7%'39`P\6E`880AK"4`9
M80%`/\D8`!AJ`V:`X0%V%`T.-#CAN6L7-KAK$X]K9CG10'8#`0#E.-$#`8-D
MTV`#R`#B7X\XX0[A(B`000:-!'#[KR(@,M$X=@,!`.6#84!QK!&]$2_1`P&#
M9()A@V0I01E!$"F!48)@'2"1@()@&4"2@()@DX""4"E`&4"4@(-1@E`=()6`
M@E`90):`@E"7@(10*4`90)B`A5&$4!T@F8"$4!E`FH"$4)N`AE`I0!E`G("'
M4890'2"=@(90&4">@(90GX`0>8A1*4$901`IB5&(4!T@$-&1@(A0&4"2@(A0
M`P&3@"9/]FWV;/9K]FKV:0L`]F@@(!!!J(T!</NO("`)`&"M`0#$Q/__6NG_
M_Y[$__\LZ?__KL3__\8O!<<$W`71##P%T")/`P'.!R9/"P#V;#"M`0!:P/__
M[/___P````#&+P3'YB\B3P+<\VX,/`.@"0`)``RM`0`)``D`"0`)`.-O)D_V
M;O9L"P`)``$``@`E<R\E<P```"]P<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R
M.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`````+W!R
M;V,O)6DO)7,`97AE`"X```!005)?5$5-4`````!005)?4%)/1TY!344`````
M.@```"5S)7,E<P``+P```%!%4DPU3$E"`````%!%4DQ,24(`4$523#5/4%0`
M````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,
M14%.````4$%27T1%0E5'````4$%27T-!0TA%````4$%27T=,3T)!3%]$14)5
M1P````!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]435!$25(``%!!4E]'3$]"
M04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`````#$```!L<V5E:R!F86EL960`
M````<F5A9"!F86EL960`3$1?3$E"4D%265]0051(`%-94U1%30``+W1M<```
M``!414U01$E2`%1-4`!54T52`````%5315).04U%`````"4P,G@`````)7,E
M<R5S)7,`````<&%R+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D
M:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N
M9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!0051(`````'!A<FP`````+G!A
M<@````!S:&]R="!R96%D```E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E
M<P```"5S)7-T96UP+25U+25U)7,`````&````'!E<FP`````,````%!!4CHZ
M4&%C:V5R.CI615)324].`````#$N,#8S````56YA8FQE('1O(&-R96%T92!C
M86-H92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C
M:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`````M90``
M+2T``&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")]
M)PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G
M92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE
M+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN
M4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").
M(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<
M,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`
M7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S
M:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I
M("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP
M;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F
M:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N
M9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("10
M05)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M
M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@
M)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@
M*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I
M<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O
M<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U
M=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ
M1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK
M('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?
M=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL
M93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z
M.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G
M+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA
M;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@
M,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?
M=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@
M,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@
M,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N
M=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A
M8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M
M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@
M9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN
M:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S
M>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@
M.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R
M?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/
M(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N
M86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S
M971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.
M5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,
M15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S
M=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@
M>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[
M("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M
M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC
M*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F
M:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N
M86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A
M="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S
M("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*
M<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N
M92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@
M8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#
M86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?
M<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D
M1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B
M=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F
M<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I
M>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L
M;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@
M("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)
M3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L
M;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA
M;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD
M77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I
M(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L
M("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*
M:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\
M86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L
M("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M
M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N
M86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL
M;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D
M9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E
M860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S
M96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@
M(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR
M971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D
M=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B
M.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ
M;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE
M(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I
M.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*
M<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H
M(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL
M97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA
M;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T
M=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F
M:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A
M9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD[
M"G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL
M96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S
M<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@
M>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL
M96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE
M(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E
M7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I
M('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN
M(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O
M<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F
M('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F
M:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@
M(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*
M:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N
M<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T
M;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S
M:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=6
M6S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!0
M7U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L
M(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!
M4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0[
M"FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS
M:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E
M<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E
M<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U
M;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@
M/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*
M96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@
M9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF
M("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'
M5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.
M5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z
M.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF
M="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER
M92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG
M97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*
M:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A
M<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*
M8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^
M;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D
M:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@
M>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G3454
M02YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@
M<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*
M?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G
M+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@
M)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R
M(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!
M1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]
M($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)
M3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W
M+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*
M)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII
M9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(
M+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL
M;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6
M>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO
M*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN
M="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@
M(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I
M.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!
M3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#
M;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@
M9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y
M;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@
M)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@
M(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H
M(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M
M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*
M96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M
M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL
M("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N
M*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F
M:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I
M<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA
M<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I
M9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@
M)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;
M4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA
M;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2![
M"B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]
M('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q
M6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC
M;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT
M96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)
M37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT
M97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE
M+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG
M=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI:
M:7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L
M(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R
M('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ
M<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M
M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=
M.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%
M04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY
M("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*
M)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA
M;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@
M)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE
M("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?
M;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*
M;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H
M+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M
M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O
M=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N
M;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q
M=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR
M97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY
M("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE
M"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P
M96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H
M+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A
M<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I
M>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I
M;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@
M<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB
M97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER
M96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*
M;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY
M("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P
M96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII
M9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E
M<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B
M('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI]
M(&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@
M(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M
M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D
M:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N
M86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U
M>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]
M*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI
M8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@
M<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R
M"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF
M="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\[
M"G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H
M+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G
M7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A
M=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET
M:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*
M<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@
M<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I
M<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*
M<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E
M<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE
M.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q
M=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O
M;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$
M:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*
M<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I
M<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R
M97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!]
M.PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A
M;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![
M(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V
M86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H
M(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U0
M1$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@
M*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@
M86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![
M*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H
M(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F
M5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*
M)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6
M>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S
M=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L
M("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?
M9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M
M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA
M;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@
M*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@
M>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@
M;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F
M+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2![
M"G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L
M96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@
M)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<[
M"B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*
M:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%
M3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM
M?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?
M5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]
M"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@
M/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S
M<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N
M)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF
M)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE
M('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO
M9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N
M86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R
M;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]
M?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D
M,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%
M3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O
M9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*
M?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L
M("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@
M)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O
M9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*
M<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A
M=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6
M>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]
M?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D
M<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US
M("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R
M;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*
M:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F
M:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/
M1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@
M,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*
M;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W
M9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#
M=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH
M/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI
M=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2![
M"G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*
M?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/
M1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O
M(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@
M/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'
M3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%
M3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE
M=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@
M>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O
M;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#
M;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H
M97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*
M?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF
M4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q
M6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@
M3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N
M86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%
M4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T52
M4D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@
M:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``$-!0TA%``!P97)L>'-I+F,`
M````````!````!`````!````1TY5```````#`````@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````?!L``"@;```!````'`,```$````L`P```0```#8#```,````X!$`
M``T`````4P``&0```.C^`0`;````!````!H```#L_@$`'`````0```#U_O]O
MC`$```4```!L"```!@```&P"```*````JP0```L````0````%0`````````#
M````(``"``(```"(`@``%`````<````7````2`\```<```!8#@``"````/``
M```)````#````!8`````````'@```!P```#[__]O`0``"/[__V_8#0``____
M;P(```#P__]O&`T``/G__V\$````````````````````````````````````
M```````````````````````````````````(``P``@`*4$%2+G!M"@````"`
M5@``\/X!````````````4!(``&P2``"($@``I!(``,`2``#<$@``^!(``!03
M```P$P``3!,``&@3``"$$P``H!,``+P3``#8$P``]!,``!`4```L%```2!0`
M`&04``"`%```G!0``+@4``#4%```\!0```P5```H%0``1!4``&`5``!\%0``
MF!4``+05``#0%0``[!4```@6```D%@``0!8``%P6``!X%@``E!8``+`6``#,
M%@``Z!8```07```@%P``/!<``%@7``!T%P``D!<``*P7``#(%P``Y!<````8
M```<&```````````````````````````````````````````````````````
M`````````````````$=#0SH@*$1E8FEA;B`Q-"XR+C`M-RD@,30N,BXP```N
M<VAS=')T86(`+FYO=&4N9VYU+F)U:6QD+6ED`"YI;G1E<G``+F=N=2YH87-H
M`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`
M+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A
M`"YE:%]F<F%M90`N;F]T92Y!0DDM=&%G`"YI;FET7V%R<F%Y`"YF:6YI7V%R
M<F%Y`"YD>6YA;6EC`"YD871A`"YG;W0`+F)S<P`N8V]M;65N=```````````
M```````````````````````````````````````````````+````!P````(`
M``!4`0``5`$``"0```````````````0`````````'@````$````"````>`$`
M`'@!```3```````````````!`````````"8```#V__]O`@```(P!``",`0``
MX`````0`````````!`````0````P````"P````(```!L`@``;`(````&```%
M`````0````0````0````.`````,````"````;`@``&P(``"K!```````````
M```!`````````$````#___]O`@```!@-```8#0``P`````0``````````@``
M``(```!-````_O__;P(```#8#0``V`T``(`````%`````@````0`````````
M7`````0````"````6`X``%@.``#P````!``````````$````#````&8````$
M````0@```$@/``!(#P``B`(```0````5````!`````P```!P`````0````8`
M``#@$0``X!$``$P``````````````"``````````:P````$````&````+!(`
M`"P2```$!@`````````````$````!````'8````!````!@```#`8```P&```
MS#H`````````````!`````````!\`````0````8`````4P```%,``"P`````
M`````````"``````````@@````$````"````+%,``"Q3``#60```````````
M```$`````````(H````!`````@````24```$E```!```````````````!```
M``````"4````!P````(````(E```")0``"````````````````0`````````
MH@````X````#````Z/X!`.C^```$```````````````$````!````*X````/
M`````P```.S^`0#L_@``!```````````````!`````0```"Z````!@````,`
M``#P_@$`\/X``!`!```%``````````0````(````PP````$````#```````"
M`````0`@```````````````$`````````,D````!`````P```"```@`@``$`
M&`$`````````````!`````0```#.````"`````,````X`0(`.`$!`!0`````
M``````````0`````````TP````$````P`````````#@!`0`>````````````
M```!`````0````$````#``````````````!6`0$`W````````````````0``
%````````
